export interface QueueConsumer {
    start(): Promise<unknown>;
    close(): Promise<unknown>;
}
export interface SyncPublisher<MessagePayloadType> {
    publish(message: MessagePayloadType): void;
}
export interface AsyncPublisher<MessagePayloadType, MessageOptions> {
    publish(message: MessagePayloadType, options: MessageOptions): Promise<unknown>;
}
export type TransactionObservabilityManager = {
    start: (transactionSpanId: string) => unknown;
    stop: (transactionSpanId: string) => unknown;
};
export type LogFn = {
    <T extends object>(obj: T, msg?: string, ...args: any[]): void;
    (obj: unknown, msg?: string, ...args: any[]): void;
    (msg: string, ...args: any[]): void;
};
export type Logger = {
    error: LogFn;
    info: LogFn;
    warn: LogFn;
    debug: LogFn;
    trace: LogFn;
    fatal: LogFn;
};
